===============================
MGLEX
===============================

This Python Package provides a probabilistic model to classify nucleotide
sequences in metagenome samples. It was developed as a framework to help
researchers to reconstruct individual genomes from such datasets using custom
workflows and to give developers the possibility to integrate the model into
their programs.

* Free software: GPLv3 license
* Source code: https://github.com/fungs/mglex

Features
--------

* Integrates nucleotide composition, multi-sample coverage
  and taxonomic annotation
* Learns a model in linear time with respect to the number of input sequences
* Classifies novel sequences in linear time
* Calculates likelihood and p-values
* Calculates probabilistic distances between genome bins

Credits
---------

This package was created using NumPy by Johannes Dröge at the Computational
Biology of Infection Research Group at the Helmholtz Centre for Infection
Research, Braunschweig, Germany.
